@@ -26,6 +26,7 @@ class Bundle:
         'max_uses': None,     # int64 - Maximum number of times bundle can be accessed
         'note': None,     # string - Bundle internal note
         'path_template': None,     # string - Template for creating submission subfolders. Can use the uploader's name, email address, ip, company, and any custom form data.
+        'send_email_receipt_to_uploader': None,     # boolean - Send delivery receipt to the uploader. Note: For writable share only
         'user_id': None,     # int64 - Bundle creator user ID
         'username': None,     # string - Bundle creator username
         'clickwrap_id': None,     # int64 - ID of the clickwrap to use with this bundle.
@@ -99,9 +100,10 @@ class Bundle:
     #   preview_only - boolean - Restrict users to previewing files only?
     #   require_registration - boolean - Show a registration page that captures the downloader's name and email address?
     #   require_share_recipient - boolean - Only allow access to recipients who have explicitly received the share via an email sent through the Files.com UI?
+    #   send_email_receipt_to_uploader - boolean - Send delivery receipt to the uploader. Note: For writable share only
+    #   skip_company - boolean - BundleRegistrations can be saved without providing company?
     #   skip_email - boolean - BundleRegistrations can be saved without providing email?
     #   skip_name - boolean - BundleRegistrations can be saved without providing name?
-    #   skip_company - boolean - BundleRegistrations can be saved without providing company?
     #   watermark_attachment_delete - boolean - If true, will delete the file stored in watermark_attachment
     #   watermark_attachment_file - file - Preview watermark image applied to all bundle items.
     def update(self, params = None):
@@ -245,6 +247,7 @@ def get(id, params = None, options = None):
 #   clickwrap_id - int64 - ID of the clickwrap to use with this bundle.
 #   inbox_id - int64 - ID of the associated inbox, if available.
 #   require_share_recipient - boolean - Only allow access to recipients who have explicitly received the share via an email sent through the Files.com UI?
+#   send_email_receipt_to_uploader - boolean - Send delivery receipt to the uploader. Note: For writable share only
 #   skip_email - boolean - BundleRegistrations can be saved without providing email?
 #   skip_name - boolean - BundleRegistrations can be saved without providing name?
 #   skip_company - boolean - BundleRegistrations can be saved without providing company?
@@ -327,9 +330,10 @@ def share(id, params = None, options = None):
 #   preview_only - boolean - Restrict users to previewing files only?
 #   require_registration - boolean - Show a registration page that captures the downloader's name and email address?
 #   require_share_recipient - boolean - Only allow access to recipients who have explicitly received the share via an email sent through the Files.com UI?
+#   send_email_receipt_to_uploader - boolean - Send delivery receipt to the uploader. Note: For writable share only
+#   skip_company - boolean - BundleRegistrations can be saved without providing company?
 #   skip_email - boolean - BundleRegistrations can be saved without providing email?
 #   skip_name - boolean - BundleRegistrations can be saved without providing name?
-#   skip_company - boolean - BundleRegistrations can be saved without providing company?
 #   watermark_attachment_delete - boolean - If true, will delete the file stored in watermark_attachment
 #   watermark_attachment_file - file - Preview watermark image applied to all bundle items.
 def update(id, params = None, options = None):
