@@ -16,7 +16,7 @@ class UsageDailySnapshot:
         'deleted_files_storage': None,     # int64 - GB of Files Native Storage used on this day for files that have been deleted and are stored as backups.
         'deleted_files_counted_in_minimum': None,     # int64 - GB of Files Native Storage used on this day for files that have been permanently deleted but were uploaded less than 30 days ago, and are still billable.
         'root_storage': None,     # int64 - GB of Files Native Storage used for the root folder.  Included here because this value will not be part of `usage_by_top_level_dir`
-        'usage_by_top_level_dir': None,     # array - Usage broken down by each top-level folder
+        'usage_by_top_level_dir': None,     # object - Usage broken down by each top-level folder
     }
 
     def __init__(self, attributes=None, options=None):
